@@ -55,11 +55,11 @@ App::Dochazka::CLI::Parser - Parser module
 
 =head1 VERSION
 
-Version 0.150
+Version 0.151
 
 =cut
 
-our $VERSION = '0.150';
+our $VERSION = '0.151';
 
 
 
@@ -158,7 +158,7 @@ sub parse {
     my $th = {};      # resulting token hash
 
     $w_cmd =~ s/^\s+//;
-    WHILE1: while ( $w_cmd ) {
+    WHILE1: while ( length( $w_cmd ) > 0 ) {
         
         # get list of possible tokens
         my $poss = possible_words( $ts );
@@ -193,7 +193,7 @@ sub parse {
         $th->{ '_REST' } = $w_cmd;
         last WHILE1;
     }
-    $th->{ '_REST' } = '' unless $th->{ '_REST' };
+    $th->{'_REST'} = '' unless exists( $th->{'_REST'} );
 
     return { ts => $ts, th => $th, nc => join( ' ', @$ts ) };
 }
@@ -248,16 +248,5 @@ sub possible_words {
 }
 
 
-#=head2 no_match
-#
-#This function is called by the semantic analyzer if no match is found.
-#
-#=cut
-#
-#sub no_match {
-#    die $CELL->status_err( 'DOCHAZKA_CLI_PARSE_ERROR' );
-#}
-
-
 1;
 
